@@ -1,8 +1,8 @@
 from DiscordUtils import Pagination
 from DiscordUtils.InviteTracker import InviteTracker
-from DiscordUtils.Music import Music
+from DiscordUtils.Music import Music, EmptyQueue, NotConnectedToVoice, NotPlaying
 
 __title__ = "DiscordUtils"
-__version__ = "1.2.5"
+__version__ = "1.2.6"
 __author__ = "toxicrecker"
 __license__ = "MIT"
\ No newline at end of file
